@@ -32,6 +32,7 @@ test_that(".check_data correctly detects wrong numeric inputs 1", {
 test_that(".check_data correctly detects wrong numeric inputs 2", {
   df <- df.SMD[1:2,]
   df$n_cases[1] <- "?"
+  df$n_controls[1] <- "!!"
   check <- grepl("The dataframe contains non-numeric characters while this is expected. Please check inputs.",
                  attr(suppressWarnings(.check_data(df)), "message"), fixed = TRUE)
   expect_equal(check, TRUE)
@@ -60,9 +61,9 @@ test_that(".check_data correctly identify wrong measure names", {
   df$measure[3] <- "a"
 
   dferror <- attr(.check_data(df), "data")
-  check <- grepl("Measure ' a ' not supported. Should be either 'SMD', 'OR', 'HR', 'IRR', 'RR', 'MD', 'G'",
+  check <- grepl("Measure ' a ' not supported",
                  attr(.check_data(df), "message"), fixed = TRUE)
-  check2 <- grepl("Measure ' a ' not supported. Should be either 'SMD', 'OR', 'HR', 'IRR', 'RR', 'MD', 'G'", dferror[dferror$row_index == 3,]$column_errors,
+  check2 <- grepl("Measure ' a ' not supported", dferror[dferror$row_index == 3,]$column_errors,
                   fixed = TRUE)
 
   expect_equal(check, TRUE)
@@ -192,9 +193,9 @@ test_that(".check_data correctly identify wrong sample size inputs: SMD", {
   df1 <- df.SMD
   df1$n_cases[3] <- NA
   dferror1 <- attr(.check_data(df1), "data")
-  verif1 <- grepl("For SMD, MD, G the number of cases/controls is mandatory",
+  verif1 <- grepl("the number of cases/controls is mandatory",
                   dferror1[dferror1$row_index == 3,]$column_errors, fixed = TRUE)
-  check1 <- grepl("For SMD, MD and G the number of cases and controls is mandatory",
+  check1 <- grepl("the number of cases and controls is mandatory",
                  attr(.check_data(df1), "message"), fixed = TRUE)
 
   expect_equal(verif1, TRUE)
@@ -203,9 +204,9 @@ test_that(".check_data correctly identify wrong sample size inputs: SMD", {
   df2 <- df.SMD
   df2$n_controls[3] <- NA
   dferror2 <- attr(.check_data(df2), "data")
-  verif2 <- grepl("For SMD, MD, G the number of cases/controls is mandatory",
+  verif2 <- grepl("the number of cases/controls is mandatory",
                   dferror2[dferror2$row_index == 3,]$column_errors, fixed = TRUE)
-  check2 <- grepl("For SMD, MD and G the number of cases and controls is mandatory",
+  check2 <- grepl("the number of cases and controls is mandatory",
                   attr(.check_data(df2), "message"), fixed = TRUE)
 
   expect_equal(verif2, TRUE)
@@ -573,35 +574,35 @@ test_that(".check_data correctly prevents users to apply a shared corrections wi
   dferror6 <- attr(.check_data(df6), "data")
   dferror7 <- attr(.check_data(df7), "data")
 
-  verif1 <- grepl("The 'shared_controls' column cannot be indicated with a 'RR' or 'IRR' effect size",
+  verif1 <- grepl("The 'shared_controls' column cannot be indicated with a 'RR' or 'IRR' measure",
                   unique(dferror1$column_errors), fixed = TRUE)
-  verif2 <- grepl("The 'shared_controls' column cannot be indicated with a 'RR' or 'IRR' effect size",
+  verif2 <- grepl("The 'shared_controls' column cannot be indicated with a 'RR' or 'IRR' measure",
                   unique(dferror2$column_errors), fixed = TRUE)
-  verif3 <- grepl("The 'shared_nexp' / 'shared_controls' columns cannot be indicated with a 'HR' effect size",
+  verif3 <- grepl("The 'shared_nexp' / 'shared_controls' columns cannot be indicated with a 'HR', 'R' or 'Z' measures",
                   unique(dferror3$column_errors), fixed = TRUE)
-  verif4 <- grepl("The 'shared_nexp' / 'shared_controls' columns cannot be indicated with a 'HR' effect size",
+  verif4 <- grepl("The 'shared_nexp' / 'shared_controls' columns cannot be indicated with a 'HR', 'R' or 'Z' measures",
                   unique(dferror4$column_errors), fixed = TRUE)
-  verif5 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'MD', 'G' effect size",
+  verif5 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'SMC', 'MD', or 'G' measure",
                   unique(dferror5$column_errors), fixed = TRUE)
-  verif6 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'MD', 'G' effect size.",
+  verif6 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'SMC', 'MD', or 'G' measure",
                   unique(dferror6$column_errors), fixed = TRUE)
-  verif7 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'MD', 'G' effect size.",
+  verif7 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'SMC', 'MD', or 'G' measure",
                   unique(dferror7$column_errors), fixed = TRUE)
 
-  check1 <- grepl("The 'shared_controls' column is only supported for the SMD, MD, G or OR measure",
+  check1 <- grepl("The 'shared_controls' column is only supported for the SMD, SMC, MD, G or OR measure",
                   attr(.check_data(df1), "message"), fixed = TRUE)
-  check2 <- grepl("The 'shared_controls' column is only supported for the SMD, MD, G or OR measure",
+  check2 <- grepl("The 'shared_controls' column is only supported for the SMD, SMC, MD, G or OR measure",
                   attr(.check_data(df2), "message"), fixed = TRUE)
-  check3 <- grepl("The 'shared_nexp' and 'shared_controls' columns are currently not supported in combination with the HR statistics.",
+  check3 <- grepl("The 'shared_nexp' and 'shared_controls' columns are not supported in combination with the HR, R and Z measures",
                   attr(.check_data(df3), "message"), fixed = TRUE)
-  check4 <- grepl("The 'shared_nexp' and 'shared_controls' columns are currently not supported in combination with the HR statistics.",
+  check4 <- grepl("The 'shared_nexp' and 'shared_controls' columns are not supported in combination with the HR, R and Z measures",
                   attr(.check_data(df4), "message"), fixed = TRUE)
 
-  check5 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'MD', 'G' effect size",
+  check5 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'SMC', 'MD', or 'G' measure",
                   attr(.check_data(df5), "message"), fixed = TRUE)
-  check6 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'MD', 'G' effect size",
+  check6 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'SMC', 'MD', or 'G' measure",
                   attr(.check_data(df6), "message"), fixed = TRUE)
-  check7 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'MD', 'G' effect size",
+  check7 <- grepl("The 'shared_nexp' column cannot be indicated with a 'SMD', 'SMC', 'MD', or 'G' measure",
                  attr(.check_data(df7), "message"), fixed = TRUE)
 
   expect_equal(check1, TRUE)
@@ -856,9 +857,9 @@ test_that(".check_data detects missing information for SMD: 1", {
   df <- df.SMD
   df$value[3] <- df$ci_lo[3] <- df$mean_cases[3] <- NA
   dferror <- attr(.check_data(df), "data")
-  verif <- grepl("Unknown confidence interval / se / var / means and SD.",
+  verif <- grepl("Unknown value of the SMD / means and SD.",
                  dferror[dferror$row_index == 3,]$column_errors, fixed = TRUE)
-  check <- grepl("SMD/MD/G measures are not associated with sufficient information to run the umbrella review.",
+  check <- grepl("SMD measure is not associated with sufficient information to run the umbrella review",
                  attr(.check_data(df), "message"), fixed = TRUE)
   expect_equal(verif, TRUE)
   expect_equal(check, TRUE)
@@ -885,9 +886,9 @@ test_that(".check_data detects missing information for MD", {
   df$measure = "MD"
   df$value[3] <- df$sd_controls[3] <- df$ci_up[3] <- NA
   dferror <- attr(.check_data(df), "data")
-  verif <- grepl("Unknown confidence interval / se / var / means and SD.",
+  verif <- grepl("Unknown value + (confidence interval / se / var) of the MD.",
                  dferror[dferror$row_index == 3,]$column_errors, fixed = TRUE)
-  check <- grepl("SMD/MD/G measures are not associated with sufficient information to run the umbrella review.",
+  check <- grepl("MD measure is not associated with sufficient information to run the umbrella review",
                  attr(.check_data(df), "message"), fixed = TRUE)
   expect_equal(check, TRUE)
 })
@@ -897,7 +898,7 @@ test_that(".check_data detects missing information for MD: 2", {
   df <- df.SMD
   df$measure = "MD"
   df$ci_up[3] <- df$ci_lo[3] <- df$se[3] <- df$mean_cases[3] <- NA
-  check <- grepl("95% CI or standard error or variance is a mandatory information when working with 'MD' measure.",
+  check <- grepl("MD measure is not associated with sufficient information to run the umbrella review",
                  attr(.check_data(df), "message"), fixed = TRUE)
   expect_equal(check, TRUE)
 })
@@ -915,9 +916,9 @@ test_that(".check_data detects missing information for HR", {
   df <- df.HR
   df$ci_lo[3] <- df$ci_up[3] <- NA
   dferror <- attr(.check_data(df), "data")
-  verif <- grepl("Unknown confidence interval / se / var of the hazard ratio.",
+  verif <- grepl("Unknown value + (confidence interval / se / var) of the HR.",
                  dferror[dferror$row_index == 3,]$column_errors, fixed = TRUE)
-  check <- grepl("95% CI or standard error or variance is a mandatory information when working with 'HR' measure",
+  check <- grepl("HR measure is not associated with sufficient information to run the umbrella review",
                  attr(.check_data(df), "message"), fixed = TRUE)
   expect_equal(verif, TRUE)
   expect_equal(check, TRUE)
@@ -938,16 +939,13 @@ test_that(".check_data detects missing CI and (n_exp|n_nexp|n_cases_exp|n_cases_
   df <- subset(df.RR, select = -c(n_exp, n_nexp))
   df$ci_lo[3] <- df$ci_up[3] <- NA
   dferror <- attr(.check_data(df), "data")
-  verif1 <- grepl("Unknown confidence interval / se / var / n_exp",
-                  dferror[dferror$row_index == 3,]$column_errors, fixed = TRUE)
-  verif2 <- grepl("Unknown confidence interval / se / var / n_nexp",
+  verif1 <- grepl("Unknown value + (confidence interval / se / var) of the RR or unknown 2x2 table.",
                   dferror[dferror$row_index == 3,]$column_errors, fixed = TRUE)
   check <- grepl("RR measure is not associated with sufficient information to run the umbrella review",
                  attr(.check_data(df), "message"), fixed = TRUE)
 
   expect_equal(check, TRUE)
   expect_equal(verif1, TRUE)
-  expect_equal(verif2, TRUE)
 
   # IRR
   df <- subset(df.IRR, select = -c(time))
@@ -956,9 +954,9 @@ test_that(".check_data detects missing CI and (n_exp|n_nexp|n_cases_exp|n_cases_
   df2$ci_lo[3] <- df2$ci_up[3] <- df2$time_nexp[3] <- NA
   dferror1 <- attr(.check_data(df1), "data")
   dferror2 <- attr(.check_data(df2), "data")
-  verif1 <- grepl("Unknown confidence interval / se / var / time_exp",
+  verif1 <- grepl("Unknown (value + (ci/se/var) + n_cases + time) OR number of cases and time for both exp and non-exp groups.",
                   dferror1[dferror1$row_index == 3,]$column_errors, fixed = TRUE)
-  verif2 <- grepl("Unknown confidence interval / se / var / time_nexp",
+  verif2 <- grepl("Unknown (value + (ci/se/var) + n_cases + time) OR number of cases and time for both exp and non-exp groups.",
                   dferror2[dferror2$row_index == 3,]$column_errors, fixed = TRUE)
   check1 <- grepl("IRR measure is not associated with sufficient information to run the umbrella review",
                  attr(.check_data(df1), "message"), fixed = TRUE)
@@ -970,3 +968,4 @@ test_that(".check_data detects missing CI and (n_exp|n_nexp|n_cases_exp|n_cases_
   expect_equal(verif1, TRUE)
   expect_equal(verif2, TRUE)
 })
+
